@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Document(object):
+class Document(TelegramObject):
     def __init__(self,
                  file_id,
                  thumb,
@@ -31,16 +31,13 @@ class Document(object):
                         mime_type=data.get('mime_type', None),
                         file_size=data.get('file_size', None))
 
-    def to_json(self):
-        json_data = {'file_id': self.file_id,
-                     'thumb': self.thumb.to_json()}
+    def to_dict(self):
+        data = {'file_id': self.file_id,
+                'thumb': self.thumb.to_dict()}
         if self.file_name:
-            json_data['file_name'] = self.file_name
+            data['file_name'] = self.file_name
         if self.mime_type:
-            json_data['mime_type'] = self.mime_type
+            data['mime_type'] = self.mime_type
         if self.file_size:
-            json_data['file_size'] = self.file_size
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['file_size'] = self.file_size
+        return data
