@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class GroupChat(object):
+class GroupChat(TelegramObject):
     def __init__(self,
                  id,
                  title):
@@ -16,10 +16,7 @@ class GroupChat(object):
         return GroupChat(id=data.get('id', None),
                          title=data.get('title', None))
 
-    def to_json(self):
-        json_data = {'id': self.id,
-                     'title': self.title}
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+    def to_dict(self):
+        data = {'id': self.id,
+                'title': self.title}
+        return data
