@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class PhotoSize(object):
+class PhotoSize(TelegramObject):
     def __init__(self,
                  file_id,
                  width,
@@ -22,13 +22,10 @@ class PhotoSize(object):
                          height=data.get('height', None),
                          file_size=data.get('file_size', None))
 
-    def to_json(self):
-        json_data = {'file_id': self.file_id,
-                     'width': self.width,
-                     'height': self.height}
+    def to_dict(self):
+        data = {'file_id': self.file_id,
+                'width': self.width,
+                'height': self.height}
         if self.file_size:
-            json_data['file_size'] = self.file_size
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['file_size'] = self.file_size
+        return data
