@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class UserProfilePhotos(object):
+class UserProfilePhotos(TelegramObject):
     def __init__(self,
                  total_count,
                  photos):
@@ -24,15 +24,12 @@ class UserProfilePhotos(object):
         return UserProfilePhotos(total_count=data.get('total_count', None),
                                  photos=photos)
 
-    def to_json(self):
-        json_data = {}
+    def to_dict(self):
+        data = {}
         if self.total_count:
-            json_data['total_count'] = self.total_count
+            data['total_count'] = self.total_count
         if self.photos:
-            json_data['photos'] = []
+            data['photos'] = []
             for photo in self.photos:
-                json_data['photos'].append([x.to_json() for x in photo])
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+                data['photos'].append([x.to_dict() for x in photo])
+        return data
