@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Video(object):
+class Video(TelegramObject):
     def __init__(self,
                  file_id,
                  width,
@@ -40,19 +40,16 @@ class Video(object):
                      file_size=data.get('file_size', None),
                      caption=data.get('caption', None))
 
-    def to_json(self):
-        json_data = {'file_id': self.file_id,
-                     'width': self.width,
-                     'height': self.height,
-                     'duration': self.duration,
-                     'thumb': self.thumb.to_json()}
+    def to_dict(self):
+        data = {'file_id': self.file_id,
+                'width': self.width,
+                'height': self.height,
+                'duration': self.duration,
+                'thumb': self.thumb.to_dict()}
         if self.mime_type:
-            json_data['mime_type'] = self.mime_type
+            data['mime_type'] = self.mime_type
         if self.file_size:
-            json_data['file_size'] = self.file_size
+            data['file_size'] = self.file_size
         if self.caption:
-            json_data['caption'] = self.caption
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['caption'] = self.caption
+        return data
